@@ -3,7 +3,13 @@ from __future__ import absolute_import, division, print_function, unicode_litera
 
 import pytest
 
-from efc.rpn_builder.parser.operands import BadReference, NumErrorOperand, ValueNotAvailable
+from efc.rpn_builder.parser.operands import (
+    BadReference,
+    NumErrorOperand,
+    ValueErrorOperand,
+    ValueNotAvailable,
+    ZeroDivisionErrorOperand,
+)
 from .mock import ExcelMock, get_calculator
 
 
@@ -46,13 +52,14 @@ def test_IF(calc):
     assert calc('IF(\'Sheet 1\'!A3 = 4,\'Sheet 1\'!C3, 0)', 'Yet another sheet').value == 8
 
 
-def test_IFS(calc):
-    assert calc('IFS(FALSE,1,FALSE,2,TRUE,3)', 'Yet another sheet').value == 3
-    assert calc('IFS(TRUE,1,FALSE,2,TRUE,3)', 'Yet another sheet').value == 1
-    assert calc('IFS(FALSE,1,TRUE,2,TRUE,3)', 'Yet another sheet').value == 2
+@pytest.mark.parametrize('prefix', ('_xlfn.', '_xludf.', ''))
+def test_IFS(calc, prefix):
+    assert calc(prefix + 'IFS(FALSE,1,FALSE,2,TRUE,3)', 'Yet another sheet').value == 3
+    assert calc(prefix + 'IFS(TRUE,1,FALSE,2,TRUE,3)', 'Yet another sheet').value == 1
+    assert calc(prefix + 'IFS(FALSE,1,TRUE,2,TRUE,3)', 'Yet another sheet').value == 2
 
     with pytest.raises(ValueNotAvailable):
-        assert calc('IFS(FALSE,1,FALSE,2,FALSE,3)', 'Yet another sheet').value == 1
+        assert calc(prefix + 'IFS(FALSE,1,FALSE,2,FALSE,3)', 'Yet another sheet').value == 1
 
 
 def test_IFERROR(calc):
@@ -174,6 +181,18 @@ def test_VLOOKUP(calc):
     assert calc('VLOOKUP(13,Sheet4!A1:B3,2)', 'Yet another sheet').value == 16
 
 
+def test_SEARCH(calc):
+    assert calc('SEARCH("abc", "abc")', 'Yet another sheet').value == 1
+    assert calc('SEARCH("abc", "abc", 1)', 'Yet another sheet').value == 1
+    assert calc('SEARCH("abc", "aabc", 1)', 'Yet another sheet').value == 2
+
+    with pytest.raises(ValueErrorOperand):
+        assert calc('SEARCH("abcd", "abc")', 'Yet another sheet').value
+
+    with pytest.raises(ValueErrorOperand):
+        assert calc('SEARCH("abcd", "abc", 1)', 'Yet another sheet').value
+
+
 def test_SMALL(calc):
     assert calc('SMALL(Sheet4!A1:B3,1)', 'Yet another sheet').value == 2
     assert calc('SMALL(Sheet4!A1:B3,2)', 'Yet another sheet').value == 4
@@ -298,3 +317,25 @@ def test_YEARFRAC(calc):
     assert calc('YEARFRAC(43405, 43465, 4)', 'Yet another sheet').value == 59 / 360
     assert calc('YEARFRAC(43889, 43890, 4)', 'Yet another sheet').value == 1 / 360
     assert calc('YEARFRAC(43889, 43891, 4)', 'Yet another sheet').value == 3 / 360
+
+
+def test_lower(calc):
+    with pytest.raises(ZeroDivisionErrorOperand):
+        _ = calc('LOWER(1/0)', 'Yet another sheet').value
+
+    assert calc('LOWER(1)', 'Yet another sheet').value == '1'
+    assert calc('LOWER("1")', 'Yet another sheet').value == '1'
+    assert calc('LOWER("TEST")', 'Yet another sheet').value == 'test'
+    assert calc('LOWER("test")', 'Yet another sheet').value == 'test'
+    assert calc('LOWER("TeSt %1234")', 'Yet another sheet').value == 'test %1234'
+
+
+def test_upper(calc):
+    with pytest.raises(ZeroDivisionErrorOperand):
+        _ = calc('UPPER(1/0)', 'Yet another sheet').value
+
+    assert calc('UPPER(1)', 'Yet another sheet').value == '1'
+    assert calc('UPPER("1")', 'Yet another sheet').value == '1'
+    assert calc('UPPER("TEST")', 'Yet another sheet').value == 'TEST'
+    assert calc('UPPER("test")', 'Yet another sheet').value == 'TEST'
+    assert calc('UPPER("TeSt %1234")', 'Yet another sheet').value == 'TEST %1234'
